@@ -1,12 +1,12 @@
 `summary.mefa` <-
-function(object, ...)
+function(object, nlist = 10, ...)
 {
 x <- object
 out <- list(
-    srich = rowSums(x$xtab > 0),
-    ninds = rowSums(x$xtab),
-    occup = colSums(x$xtab > 0),
-    abund = colSums(x$xtab),
+    s.rich = rowSums(x$xtab > 0),
+    s.abu = rowSums(x$xtab),
+    t.occ = colSums(x$xtab > 0),
+    t.abu = colSums(x$xtab),
     ntot = sum(x$xtab),
     mfill = sum(x$xtab > 0)/(dim(x)[1]*dim(x)[2]),
     nsamp = dim(x)[1],
@@ -18,5 +18,6 @@ out <- list(
     drop.zero = attr(x, "drop.zero"),
     xtab.fixed = attr(x, "xtab.fixed"))
 class(out) <- c("summary.mefa")
+attr(out, "nlist") <- nlist
 return(out)}
 
